@@ -39,19 +39,48 @@ AboutDialog::AboutDialog( QWidget *parent, const char *name)
 				"<ul>"
 					"<li>Please ask general questions about vym  on "
 				"<a href=\"mailto:vym-forum@lists.sourceforge.net\">vym-forum</a></li>"
-				"<li>Subscribe/Unsubscribe and archives can be found  <a href=\"https://sourceforge.net/mail/?group_id=127802\">here</a></li>"
+				"<li>Subscribe/Unsubscribe and archives can be found  "
+				"<a href=\"https://sourceforge.net/mail/?group_id=127802\">here</a></li>"
 				"</ul>"
 		"</ul>"		
 	"<li> Credits " 
 	"<ul>"
-	"<li>Peter Adams for documentation proofreading and polishing</li>"
-	"<li>Jakob Hilmer for image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
-	"<li>Thomas Schraitle for the stylesheet  used for XHTML-export and help with XML processing in general</li>"
-	"<li>Debianization by Christoph Thielecke and Steffen Joeris</li>"
-	"<li>Matt from <a href=\"http://www.satbp.com\">www.satbp.com</a> for <a href=\"http://www.taskjuggler.org\">Taskjuggler</a> export</li>"
-	"<li>Olaf Hering for support with my Powerbook</li>"
-	"<li>All the guys at Trolltech for their Qt toolkit</li>"
-	"<li>All the guys at SuSE for their Linux and support, e.g. to get Linux running on PowerPC and also Macbooks</li>"
+	"<li>Documentation"
+	"  <ul>"
+	"    <li>Peter Adams: documentation proofreading and polishing</li>"
+	"  </ul>"
+	"</li>"
+	"<li>Translation"
+	"  <ul>"
+	"    <li>Spanish: <a href=\"http://ieee.udistrital.edu.co/aclibre\">"
+	"                 ACLibre (Academia y Conocimiento Libre)</a> </li>"
+	"    <li>French: Philippe Caillaud and Claude </li>"
+	"    <li>Italian: Seyed Puria Nafisi Azizi </li>"
+	"    <li>Brasilian: Amadeu Júnior</li>"
+	"    <li>Russion: Anton Olenev</li>"
+	"    <li>Simplified Chinese: Moligaloo</li>"
+	"  </ul>"
+	"</li>"
+	"<li> Patches"
+	"  <ul>"
+	"    <li>Konstantin Goudkov: sort branches</li>"
+	"    <li>Jakob Hilmer: image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
+	"    <li>Xavier Oswald, Christoph Thielecke and Steffen Joeris: Debian packaging</li>"
+	"    <li>Andrew Ng, Juha Ruotsalainen and Thomas Kriener: Windows</li>"
+	"    <li>Matt from <a href=\"http://www.satbp.com\">www.satbp.com</a>: "
+	"        <a href=\"http://www.taskjuggler.org\">Taskjuggler</a> export</li>"
+	"    <li>Thomas Schraitle for the stylesheet"  
+	"        used for XHTML-export and help with XML processing in general</li>"
+	"  </ul>"
+	"</li>"
+	"<li> General"
+	"  <ul>"
+	"    <li>Olaf Hering for support with my Powerbook</li>"
+	"    <li>All the guys at Trolltech for their Qt toolkit</li>"
+	"    <li>All the guys at SuSE for their Linux and support,"
+	"        e.g. to get Linux running on PowerPC and also Macbooks</li>"
+	"  </ul>"
+	"</li>"
 	"</ul>"
 	"</li>");
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
