@@ -13,15 +13,24 @@ public:
 	bool operator== ( AnimPoint  );
 	void init();
 	void copy(AnimPoint other);
+	void setStart (const QPointF &);
+	QPointF getStart();
 	void setDest (const QPointF &);
+	QPointF getDest();
+	void setTicks (const uint &t);
+	uint getTicks();
 	void setAnimated(bool);
 	bool isAnimated ();
-	void animate();
+	bool animate();
 
 private:
-	QPointF currentPos;
+	void initVector();
+
+	QPointF startPos;
 	QPointF destPos;
+	QPointF vector;
 	qreal n;
+	qreal animTicks;
     bool animated;
 
 };
