@@ -1,7 +1,12 @@
 #include "branchobj.h"
-#include "texteditor.h"
+
+// #include "texteditor.h"
+#include "geometry.h"
 #include "mapeditor.h"
 #include "mainwindow.h"
+#include "misc.h"
+
+class TextEditor;
 
 extern TextEditor *textEditor;
 extern Main *mainWindow;
@@ -48,6 +53,14 @@ BranchObj::BranchObj (QGraphicsScene* s, LinkableMapObj* p):OrnamentedObj (s)
 
 BranchObj::~BranchObj ()
 {
+	// If I'm animated, I need to un-animate myself first
+	if (anim.isAnimated() )
+	{
+		anim.setAnimated (false);
+		mapEditor->getModel()->stopAnimation (this);
+	}
+
+
 	//cout << "Destr BranchObj of "<<this<<endl;
 	// Check, if this branch was the last child to be deleted
 	// If so, unset the scrolled flags
@@ -366,15 +379,17 @@ void BranchObj::setLinkColor ()
 	// BranchObj can use color of heading
 
 	if (mapEditor)
+	{
 		if (mapEditor->getMapLinkColorHint()==HeadingColor)
 			LinkableMapObj::setLinkColor (heading->getColor() );
 		else	
 			LinkableMapObj::setLinkColor ();
+	}		
 }
 
 void BranchObj::setColorSubtree(QColor col)
 {
-	OrnamentedObj::setColor (col);
+	setColor (col);
 	for (int i=0; i<branch.size(); ++i)
 		branch.at(i)->setColorSubtree(col);
 }
@@ -684,12 +699,12 @@ LinkableMapObj* BranchObj::findMapObj(QPointF p, LinkableMapObj* excludeLMO)
 	
 
 	// Search myself
-    if (inBox (p) && (this != excludeLMO) && isVisibleObj() ) 
+    if (inBox (p,clickBox) && (this != excludeLMO) && isVisibleObj() ) 
 		return this;
 
 	// Search float images
     for (int i=0; i<floatimage.size(); ++i )
-		if (floatimage.at(i)->inBox(p) && 
+		if (inBox(p,floatimage.at(i)->getClickBox()) && 
 			(floatimage.at(i) != excludeLMO) && 
 			floatimage.at(i)->getParObj()!= excludeLMO &&
 			floatimage.at(i)->isVisibleObj() 
@@ -734,12 +749,14 @@ void BranchObj::setHeading(QString s)
 
 void BranchObj::setHideTmp (HideTmpMode mode)
 {
-	if (mode==HideExport && hasHiddenExportParent(this))
+	if (mode==HideExport && (hideExport|| hasHiddenExportParent() ) )
 	{
+		// Hide stuff according to hideExport flag and parents
 		setVisibility (false);
 		hidden=true;
 	}else
 	{
+		// Do not hide, but still take care of scrolled status
 		if (hasScrolledParent(this))
 			setVisibility (false);
 		else
@@ -747,20 +764,21 @@ void BranchObj::setHideTmp (HideTmpMode mode)
 		hidden=false;
 	}	
 
+	// And take care of my childs
 	for (int i=0; i<branch.size(); ++i)
 		branch.at(i)->setHideTmp (mode);
 }
 
-bool BranchObj::hasHiddenExportParent(BranchObj *start)
+bool BranchObj::hasHiddenExportParent()
 {
 	// Calls parents recursivly to
-	// find out, if we are temp. hidden
+	// find out, if we or parents are temp. hidden
 
-	if (hideExport) return true;
+	if (hidden || hideExport) return true;
 
-	BranchObj* bo=(BranchObj*)(parObj);
+	BranchObj* bo=(BranchObj*)parObj;
 	if (bo) 
-		return bo->hasHiddenExportParent(start);
+		return bo->hasHiddenExportParent();
 	else
 		return false;
 }
@@ -796,12 +814,12 @@ QString BranchObj::saveToDir (const QString &tmpdir,const QString &prefix, const
 	// Providing an ID for a branch makes export to XHTML easier
 	QString idAttr;
 	if (countXLinks()>0)
-		idAttr=attribut ("id",getSelectString());
+		idAttr=attribut ("id",mapEditor->getModel()->getSelectString(this)); //TODO directly access model
 	else
 		idAttr="";
 
     s=beginElement ("branch" 
-		+getOrnAttr() 
+		+getOrnXMLAttr() 
 		+scrolledAttr 
 		+areaAttr 
 		+idAttr 
@@ -1238,6 +1256,27 @@ BranchObj* BranchObj::moveBranchDown(BranchObj* bo1)// modify my childlist
 		return NULL;
 }
 
+void BranchObj::sortChildren()
+{
+	int childCount=branch.count();
+	int curChildIndex;
+	bool madeChanges=false;
+	do
+	{
+		madeChanges=false;
+		for(curChildIndex=1;curChildIndex<childCount;curChildIndex++){
+			BranchObj* curChild=(BranchObj*)branch.at(curChildIndex);
+			BranchObj* prevChild=(BranchObj*)branch.at(curChildIndex-1);
+			if(prevChild->heading->text().compare(curChild->heading->text())>0)
+			{
+				this->moveBranchUp(curChild);
+				madeChanges=true;
+			}
+		}
+	}while(madeChanges);
+}
+
+
 BranchObj* BranchObj::linkTo (BranchObj* dst, int pos)
 {
 	// Find current parent and 
@@ -1271,17 +1310,19 @@ BranchObj* BranchObj::linkTo (BranchObj* dst, int pos)
 	}	
 }
 
-void BranchObj::alignRelativeTo (QPointF ref)
+void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
 {
 	qreal th = bboxTotal.height();	
 // TODO testing
 /*
-	cout << "BO::alignRelTo "<<getHeading().ascii()<<endl;
-	cout << "  d="<<depth<<
+	QPointF pp; if (parObj) pp=parObj->getChildPos();
+	cout << "BO::alignRelTo "<<qPrintable (getHeading());
+	cout << "    d="<<depth<<
 		"  ref="<<ref<<
 //		"  bbox.topLeft="<<bboxTotal.topLeft()<<
 		"  absPos="<<absPos<<
 		"  relPos="<<relPos<<
+		"  parPos="<<pp<<
 		"  orient="<<orientation<<
 //		"  pad="<<topPad<<","<<botPad<<","<<leftPad<<","<<rightPad<<
 //		"  hidden="<<hidden<<
@@ -1310,20 +1351,28 @@ void BranchObj::alignRelativeTo (QPointF ref)
     {
 		// Align myself depending on orientation and parent, but
 		// only if I am not a mainbranch or mapcenter itself
-		LinkableMapObj::Orientation o;
-		o=parObj->getOrientation();
-		switch (orientation) 
+
+		if (anim.isAnimated())
 		{
-			case LinkableMapObj::LeftOfCenter:
-				move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
-			break;
-			case LinkableMapObj::RightOfCenter:	
-				move (ref.x() , ref.y() + (th-bbox.height())/2  );
-			break;
-			default:
-				qWarning ("LMO::alignRelativeTo: oops, no orientation given...");
-			break;
-		}		
+			move2RelPos(anim);
+		} else
+		{
+			LinkableMapObj::Orientation o;
+			o=parObj->getOrientation();
+			if (alignSelf)
+				switch (orientation) 
+				{
+					case LinkableMapObj::LeftOfCenter:
+						move (ref.x() - bbox.width(), ref.y() + (th-bbox.height())/2 );
+					break;
+					case LinkableMapObj::RightOfCenter:	
+						move (ref.x() , ref.y() + (th-bbox.height())/2  );
+					break;
+					default:
+						qWarning ("LMO::alignRelativeTo: oops, no orientation given...");
+					break;
+				}	
+		}
     }		
 
 	if (scrolled) return;
@@ -1345,7 +1394,7 @@ void BranchObj::alignRelativeTo (QPointF ref)
     {	
 		if (!branch.at(i)->isHidden())
 		{
-			branch.at(i)->alignRelativeTo (ref2);
+			branch.at(i)->alignRelativeTo (ref2,true);
 			ref2.setY(ref2.y() + branch.at(i)->getBBoxSizeWithChilds().height() );
 		}
     }
@@ -1356,7 +1405,7 @@ void BranchObj::reposition()
 {	
 /* TODO testing only
 	if (!getHeading().isEmpty())
-		cout << "BO::reposition  "<<getHeading().ascii()<<endl;
+		cout << "BO::reposition  "<<qPrintable(getHeading())<<endl;
 	else	
 		cout << "BO::reposition  ???"<<endl;
 
@@ -1393,6 +1442,28 @@ void BranchObj::unsetAllRepositionRequests()
 }
 
 
+QPolygonF BranchObj::shape()
+{
+	QPolygonF p;
+
+	QRectF r=getTotalBBox();
+	if (orientation==LinkableMapObj::LeftOfCenter)
+		p   <<r.bottomLeft()
+			<<r.topLeft()
+			<<QPointF (bbox.topLeft().x(), r.topLeft().y() )
+			<<bbox.topRight()
+			<<bbox.bottomRight()
+			<<QPointF (bbox.bottomLeft().x(), r.bottomLeft().y() ) ;
+	else		
+		p   <<r.bottomRight()
+			<<r.topRight()
+			<<QPointF (bbox.topRight().x(), r.topRight().y() )
+			<<bbox.topLeft()
+			<<bbox.bottomLeft()
+			<<QPointF (bbox.bottomRight().x(), r.bottomRight().y() ) ;
+	return p;
+}
+
 QRectF BranchObj::getTotalBBox()
 {
 	QRectF r=bbox;
@@ -1536,22 +1607,23 @@ void BranchObj::unselect()
 
 QString BranchObj::getSelectString()
 {
-	QString s;
-	if (parObj)
-	{
-		if (depth==1)
-			s= "bo:" + QString("%1").arg(getNum());
-		else	
-			s= ((BranchObj*)(parObj))->getSelectString() + ",bo:" + QString("%1").arg(getNum());
-	} else
-		s="mc:";
-	return s;
+	return mapEditor->getModel()->getSelectString (this);
 }
 
-
-void BranchObj::animate()
+void BranchObj::setAnimation(const AnimPoint &ap)
 {
-	//relPos.animate();
-	cout << "BO::animate  x,y="<<relPos.x()<<","<<relPos.y()<<endl;
+	anim=ap;
+}
+
+bool BranchObj::animate()
+{
+	anim.animate ();
+	if ( anim.isAnimated() )
+	{
+		setRelPos (anim);
+		return true;
+	}
+	parObj->reposition();	// object might have been relinked meanwhile
+	return false;
 }
 
