@@ -5,10 +5,16 @@
 
 #include <QDialog>
 #include <QCloseEvent>
+#include <QtGui>
 
+
+#include "attributedelegate.h"
 #include "branchobj.h"
 #include "mapeditor.h"
 
+
+class QAbstractItemModel;
+
 class BranchPropertyWindow:public QDialog
 {
 	Q_OBJECT
@@ -27,6 +33,8 @@ private slots:
 	void linkHideUnselectedChanged (int);
 	void incImgVerChanged (int);
 	void incImgHorChanged (int);
+	void addAttributeClicked();
+	void deleteAttributeClicked();
 
 signals:
 	void windowClosed();
@@ -45,6 +53,10 @@ private:
 
 	QColor penColor;
 	QColor brushColor;
+
+	QAbstractItemModel *attributeModel;
+
+	AttributeDelegate delegate;
 };
 
 #endif // 
