@@ -17,7 +17,7 @@ class ExportOOFileDialog:public QFileDialog
 public:
 	ExportOOFileDialog();
 
-	ExportOOFileDialog (QWidget * parent = 0, const  QString &caption=QString());
+	ExportOOFileDialog (QWidget * parent , const  QString &caption=QString());
 	bool foundConfig();
 	QString selectedConfig();
 	QString selectedFile();
