@@ -14,7 +14,7 @@ ExportBase::ExportBase()
 {
 	indentPerDepth="  ";
 	bool ok;
-    tmpDir.setPath (makeUniqueDir(ok,"/tmp/vym-export-XXXXXX"));
+    tmpDir.setPath (makeTmpDir(ok,"vym-export"));
 	if (!tmpDir.exists() || !ok)
 		QMessageBox::critical( 0, QObject::tr( "Error" ),
 					   QObject::tr("Couldn't access temporary directory\n"));
@@ -42,9 +42,9 @@ QString ExportBase::getFile ()
 	return outputFile;
 }
 
-void ExportBase::setMapCenter(MapCenterObj *mc)
+void ExportBase::setModel(VymModel *m)
 {
-	mapCenter=mc;
+	model=m;
 }
 
 void ExportBase::setCaption (const QString &s)
@@ -59,9 +59,10 @@ void ExportBase::addFilter(const QString &s)
 
 bool ExportBase::execDialog()
 {
-	if (mapCenter && mapCenter->getMapEditor())
+	//MapEditor *me=model.getMapEditor(); FIXME needed?
+	// if (model->mapCenters.count() && me)
 	{
-		QFileDialog *fd=new QFileDialog( mapCenter->getMapEditor(), caption);
+		QFileDialog *fd=new QFileDialog( 0, caption);
 		fd->setFilter (filter);
 		fd->setCaption(caption);
 		fd->setMode( QFileDialog::AnyFile );
@@ -142,42 +143,64 @@ void ExportASCII::doExport()
 
 	// Main loop over all branches
 	QString s;
-	QString actIndent("");
-	int i,j;
+	QString curIndent;
+	int i;
 	BranchObj *bo;
-	bo=mapCenter->first();
+	bo=model->first();
 	while (bo) 
 	{
 		// Make indentstring
-		for (i=0;i<bo->getDepth();i++) actIndent+= indentPerDepth;
+		curIndent="";
+		for (i=0;i<bo->getDepth()-1;i++) curIndent+= indentPerDepth;
 
-		if (bo->getDepth()==0)
+		if (!bo->hasHiddenExportParent() )
 		{
-			ts << (bo->getHeading()+ "\n");
-			for (j=0;j<bo->getHeading().length();j++) ts<<"=";
-			ts << "\n";
-		} else 	if (bo->getDepth()==1)
-			ts << ("\n"+getSectionString(bo) + bo->getHeading()+ "\n");
-		else	if (bo->getDepth()==2)
-			ts << (actIndent + " * " + bo->getHeading()+ "\n");
-		else	if (bo->getDepth()==3)
-			ts << (actIndent + " o " + bo->getHeading()+ "\n");
-		else	
-			ts << (actIndent + " - " + bo->getHeading()+ "\n");
-		
-		// If necessary, write note
-		if (!bo->getNote().isEmpty())
-		{
-			s =bo->getNoteASCII();
-			s=s.replace ("\n","\n"+actIndent);
-			ts << (s+"\n\n");
+			switch (bo->getDepth())
+			{
+				case 0:
+					ts << underline (bo->getHeading(),QString("="));
+					ts << "\n";
+					break;
+				case 1:
+					ts << "\n";
+					ts << (underline (getSectionString(bo) + bo->getHeading(), QString("-") ) );
+					ts << "\n";
+					break;
+				case 2:
+					ts << "\n";
+					ts << (curIndent + "* " + bo->getHeading());
+					ts << "\n";
+					break;
+				case 3:
+					ts << (curIndent + "- " + bo->getHeading());
+					ts << "\n";
+					break;
+				default:
+					ts << (curIndent + "- " + bo->getHeading());
+					ts << "\n";
+					break;
+			}
+
+			// If necessary, write note
+			if (!bo->getNote().isEmpty())
+			{
+				curIndent +="  | ";
+				s=bo->getNoteASCII( curIndent, 80);
+				ts << s;
+			}
 		}
-		bo=bo->next();
-		actIndent="";
+		bo=model->next(bo);
 	}
 	file.close();
 }
 
+QString ExportASCII::underline (const QString &text, const QString &line)
+{
+	QString r=text + "\n";
+	for (int j=0;j<text.length();j++) r+=line;
+	return r;
+}
+
 
 ////////////////////////////////////////////////////////////////////////
 void ExportCSV::doExport()
@@ -195,29 +218,32 @@ void ExportCSV::doExport()
 
 	// Main loop over all branches
 	QString s;
-	QString actIndent("");
+	QString curIndent("");
 	int i;
 	BranchObj *bo;
-	bo=mapCenter->first();
+	bo=model->first();
 	while (bo) 
 	{
-		// If necessary, write note
-		if (!bo->getNote().isEmpty())
+		if (!bo->hasHiddenExportParent() )
 		{
-			s =bo->getNoteASCII();
-			s=s.replace ("\n","\n"+actIndent);
-			ts << ("\""+s+"\",");
-		} else
-			ts <<"\"\",";
+			// If necessary, write note
+			if (!bo->getNote().isEmpty())
+			{
+				s =bo->getNoteASCII();
+				s=s.replace ("\n","\n"+curIndent);
+				ts << ("\""+s+"\",");
+			} else
+				ts <<"\"\",";
 
-		// Make indentstring
-		for (i=0;i<bo->getDepth();i++) actIndent+= "\"\",";
+			// Make indentstring
+			for (i=0;i<bo->getDepth();i++) curIndent+= "\"\",";
 
-		// Write heading
-		ts << actIndent << "\"" << bo->getHeading()<<"\""<<endl;
+			// Write heading
+			ts << curIndent << "\"" << bo->getHeading()<<"\""<<endl;
+		}
 		
-		bo=bo->next();
-		actIndent="";
+		bo=model->next(bo);
+		curIndent="";
 	}
 	file.close();
 }
@@ -225,8 +251,7 @@ void ExportCSV::doExport()
 ////////////////////////////////////////////////////////////////////////
 void ExportKDEBookmarks::doExport() 
 {
-	MapEditor *me=NULL;
-	if (mapCenter) me=mapCenter->getMapEditor();
+	MapEditor *me=model->getMapEditor();
 	if (me)
 	{
 		WarningDialog dia;
@@ -261,8 +286,7 @@ void ExportKDEBookmarks::doExport()
 ////////////////////////////////////////////////////////////////////////
 void ExportFirefoxBookmarks::doExport() 
 {
-	MapEditor *me=NULL;
-	if (mapCenter) me=mapCenter->getMapEditor();
+	MapEditor *me=model->getMapEditor();
 	if (me)
 	{
 		WarningDialog dia;
@@ -301,8 +325,7 @@ void ExportFirefoxBookmarks::doExport()
 ////////////////////////////////////////////////////////////////////////
 void ExportTaskjuggler::doExport() 
 {
-	MapEditor *me=NULL;
-	if (mapCenter) me=mapCenter->getMapEditor();
+	MapEditor *me=model->getMapEditor();
 	if (me)
 	{
 		me->exportXML(tmpDir.path(),false);
@@ -335,34 +358,37 @@ void ExportLaTeX::doExport()
   
   // Main loop over all branches
   QString s;
-  // QString actIndent("");
+  // QString curIndent("");
   // int i;
   BranchObj *bo;
-  bo=mapCenter->first();
+  bo=model->first();
   while (bo) {
-	if (bo->getDepth()==0);
-	else if (bo->getDepth()==1) {
-	  ts << ("\\chapter{" + bo->getHeading()+ "}\n");
+	if (!bo->hasHiddenExportParent() )
+	{
+		if (bo->getDepth()==0);
+		else if (bo->getDepth()==1) {
+		  ts << ("\\chapter{" + bo->getHeading()+ "}\n");
+		}
+		else if (bo->getDepth()==2) {
+		  ts << ("\\section{" + bo->getHeading()+ "}\n");
+		}
+		else if (bo->getDepth()==3) {
+		  ts << ("\\subsection{" + bo->getHeading()+ "}\n");
+		}
+		else if (bo->getDepth()==4) {
+		  ts << ("\\subsubsection{" + bo->getHeading()+ "}\n");
+		}
+		else {
+		  ts << ("\\paragraph*{" + bo->getHeading()+ "}\n");
+		}
+		
+		// If necessary, write note
+		if (!bo->getNote().isEmpty()) {
+		  ts << (bo->getNoteASCII());
+		  ts << ("\n");
+		}
 	}
-	else if (bo->getDepth()==2) {
-	  ts << ("\\section{" + bo->getHeading()+ "}\n");
-	}
-	else if (bo->getDepth()==3) {
-	  ts << ("\\subsection{" + bo->getHeading()+ "}\n");
-	}
-	else if (bo->getDepth()==4) {
-	  ts << ("\\subsubsection{" + bo->getHeading()+ "}\n");
-	}
-	else {
-	  ts << ("\\paragraph*{" + bo->getHeading()+ "}\n");
-	}
-	
-	// If necessary, write note
-	if (!bo->getNote().isEmpty()) {
-	  ts << (bo->getNoteASCII());
-	  ts << ("\n");
-	}
-    bo=bo->next();
+    bo=model->next(bo);
    }
   file.close();
 }
@@ -386,22 +412,25 @@ QString ExportOO::buildList (BranchObj *current)
     bo=current->getFirstBranch();
     if (bo)
     {
-        // Start list
-        r+="<text:list text:style-name=\"vym-list\">\n";
-        while (bo)
-        {
-			r+="<text:list-item><text:p >";
-			r+=quotemeta(bo->getHeading());
-			// If necessary, write note
-			if (!bo->getNote().isEmpty())
-				r+=bo->getNoteOpenDoc();
-			r+="</text:p>";
-			r+=buildList (bo);	// recursivly add deeper branches
-			r+="</text:list-item>\n";
-			i++;
-			bo=current->getBranchNum(i);
-        }
-        r+="</text:list>\n";
+		if (!bo->hasHiddenExportParent() )
+		{
+			// Start list
+			r+="<text:list text:style-name=\"vym-list\">\n";
+			while (bo)
+			{
+				r+="<text:list-item><text:p >";
+				r+=quotemeta(bo->getHeading());
+				// If necessary, write note
+				if (!bo->getNote().isEmpty())
+					r+=bo->getNoteOpenDoc();
+				r+="</text:p>";
+				r+=buildList (bo);	// recursivly add deeper branches
+				r+="</text:list-item>\n";
+				i++;
+				bo=current->getBranchNum(i);
+			}
+			r+="</text:list>\n";
+		}
     }
     return r;
 }
@@ -411,6 +440,7 @@ void ExportOO::exportPresentation()
 {
 	QString allPages;
 
+/* FIXME not adapted to multiple mapCenters yet
 	// Insert new content
 	content.replace ("<!-- INSERT TITLE -->",quotemeta(mapCenter->getHeading()));
 	content.replace ("<!-- INSERT AUTHOR -->",quotemeta(mapCenter->getAuthor()));
@@ -424,7 +454,7 @@ void ExportOO::exportPresentation()
     int j=0;
 
 	// Walk sections
-	while (sectionBO)
+	while (sectionBO && !sectionBO->hasHiddenExportParent() )
 	{
 		if (useSections)
 		{
@@ -442,7 +472,7 @@ void ExportOO::exportPresentation()
 		// Walk mainpages
 		pagesBO=sectionBO->getFirstBranch();
 		j=0;
-		while (pagesBO)
+		while (pagesBO && !pagesBO->hasHiddenExportParent() )
 		{
 			// Add page with list of items
 			onePage=pageTemplate;
@@ -474,6 +504,7 @@ void ExportOO::exportPresentation()
 
 	// zip tmpdir to destination
 	zipDir (tmpDir,outputFile);	
+*/
 }
 
 bool ExportOO::setConfigFile (const QString &cf)
