@@ -7,6 +7,7 @@
 
 #include "mapcenterobj.h"
 #include "settings.h"
+#include "vymmodel.h"
 
 
 /*! \brief Base class for all exports
@@ -22,18 +23,18 @@ public:
 	virtual void setDir(const QDir&);
 	virtual void setFile(const QString &);
 	virtual QString getFile ();
-	virtual void setMapCenter (MapCenterObj*);
+	virtual void setModel (VymModel *m);
 	virtual void setCaption(const QString &);
 	virtual void addFilter (const QString &);
 	virtual bool execDialog();
 	virtual bool canceled();
 protected:  
+	VymModel *model;
 	virtual QString getSectionString (BranchObj*);
 
 	QDir tmpDir;
 	QDir outDir;
 	QString outputFile;
-	MapCenterObj *mapCenter;
 	QString	indentPerDepth;
 	QString caption;
 	QString filter;
@@ -46,6 +47,7 @@ class ExportASCII:public ExportBase
 public:
 	ExportASCII();
 	virtual void doExport();
+	virtual QString underline (const QString &text, const QString &line);
 };
 
 ///////////////////////////////////////////////////////////////////////
