@@ -1,4 +1,5 @@
 #include "flagrowobj.h"
+#include "geometry.h"
 
 #include <QToolBar>
 
@@ -109,9 +110,9 @@ void FlagRowObj::calcBBoxSize()
 
 QString FlagRowObj::getFlagName (const QPointF &p)
 {
-	if (!inBox (p)) return "";
+	if (!inBox (p,clickBox)) return "";
 	for (int i=0; i<flag.size(); ++i)
-		if (flag.at(i)->inBox (p)) return flag.at(i)->getName();
+		if (inBox (p,flag.at(i)->getClickBox ())) return flag.at(i)->getName();
 	return "";	
 
 	
