@@ -1,15 +1,21 @@
 #ifndef FLAGROWOBJ_H
 #define FLAGROWOBJ_H
 
-#include <qmainwindow.h>
+#include <QMainWindow>
 
 #include "mapobj.h"
 #include "flagobj.h"
 
-class FlagRowObj:public QObject,public MapObj {
+/*! \brief A collection of flags (FlagObj). 
+
+   The flags are aligned horizontally  in a row on the map. 
+   A toolbar can be created from the flags in this row.
+ */
+
+class FlagRowObj:public MapObj {
 public:
     FlagRowObj ();
-    FlagRowObj (QCanvas*);
+    FlagRowObj (QGraphicsScene *);
     ~FlagRowObj ();
     virtual void init ();
     virtual void copy (FlagRowObj*);
@@ -20,13 +26,14 @@ public:
     virtual FlagObj* addFlag (FlagObj *fo);			// make deep copy of FlagObj
     virtual void positionBBox();
     virtual void calcBBoxSize();
-	virtual QString getFlagName (const QPoint &p);	// Find flag by position
+	virtual QString getFlagName (const QPointF &p);	// Find flag by position
 	bool isActive(const QString&);
 	void toggle (const QString&,bool);
 	void activate(const QString&);
 	void deactivate(const QString&);
 	void deactivateAll();
 	void deactivateGroup(FlagObj *);
+	void setToolBar (QToolBar *);
 	void setEnabled (bool);
 	void setShowFlags (bool);
 	void resetUsedCounter();
@@ -37,7 +44,8 @@ public:
 private:	
 	FlagRowObj* parentRow;					// look for flags in this row
 	FlagObj* findFlag (const QString&);
-    QPtrList <FlagObj> flag; 
+    QList <FlagObj*> flag; 
+	QToolBar *toolbar;
 	QString name;
 	bool showFlags;							// FloatObjects want to hide their flags
 };
