@@ -11,7 +11,7 @@ extern QDir vymBaseDir;
 ImportBase::ImportBase()
 {
 	bool ok;
-    tmpDir.setPath (makeUniqueDir(ok,"/tmp/vym-import-XXXXXX"));
+    tmpDir.setPath (makeTmpDir(ok,"vym-import"));
 	if (!tmpDir.exists() || !ok)
 		QMessageBox::critical( 0, QObject::tr( "Error" ),
 					   QObject::tr("Couldn't access temporary directory\n"));
