@@ -6,6 +6,11 @@
 #include "settings.h"
 #include "version.h"
 
+#if defined(Q_OS_WIN32)
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#endif
+
 // Global variables
 TextEditor *textEditor;			// used in Constr. of LinkableMapObj
 								// initialized in mainwindow
@@ -21,6 +26,9 @@ QString clipboardFile;			// Clipboard used in all mapEditors
 QDir vymBaseDir;				// Containing all styles, scripts, images, ...
 QDir lastImageDir;
 QDir lastFileDir;
+#if defined(Q_OS_WIN32)
+QDir vymInstallDir;
+#endif
 QString iconPath;				// Pointing to icons used for toolbars
 QString flagsPath;				// Pointing to flags
 bool clipboardEmpty;			
@@ -65,7 +73,7 @@ int main(int argc, char* argv[])
 		"http://www.InSilmaril.de/vym\n");
 	if (options.parse())
 	{
-		cout << endl << options.getHelpText().ascii()<<endl;
+		cout << endl << qPrintable( options.getHelpText())<<endl;
 		return 1;
 	}
 
@@ -97,6 +105,27 @@ int main(int argc, char* argv[])
 		#if defined (Q_OS_MACX)
 			vymBaseDir.setPath(vymBaseDir.currentDirPath() +"/vym.app/Contents/Resources");
 
+        #elif defined (Q_OS_WIN32)
+            QString basePath;
+
+            wchar_t wbuf[512];
+            if (GetModuleFileName(NULL, wbuf, 512))
+            {
+                QString mfn(QString::fromWCharArray(wbuf));
+                mfn.replace('\\', '/');
+                if (mfn.endsWith("/bin/vym.exe", Qt::CaseInsensitive))
+                {
+                    mfn.chop(12);
+                    basePath = mfn;
+                }
+            }
+
+            if (basePath.isEmpty())
+                basePath = vymBaseDir.currentDirPath();
+
+            vymInstallDir.setPath(basePath);
+            vymBaseDir.setPath(basePath + "/share/vym");
+
 		#else
 			vymBaseDir.setPath ("/usr/share/vym");
 			if (!vymBaseDir.exists())
@@ -117,7 +146,7 @@ int main(int argc, char* argv[])
 
 	if (options.isOn ("help"))
 	{
-		cout << options.getHelpText().ascii()<<endl;
+		cout << qPrintable (options.getHelpText())<<endl;
 		return 0;	
 	}	
 
@@ -137,7 +166,12 @@ int main(int argc, char* argv[])
 	textEditor->setIcon (QPixmap (iconPath+"vym-editor.png"));
 
 	// Initialize mainwindow 
+#if defined(Q_OS_WIN32)
+    Main m(0, 0, (Qt::Window | Qt::MSWindowsOwnDC));
+#else
     Main m;
+#endif
+
 	//m.resize(m.sizeHint());
 	m.setIcon (QPixmap (iconPath+"vym-48x48.png"));
 	m.show();
@@ -178,4 +212,3 @@ int main(int argc, char* argv[])
 
     return app.exec();
 }
-
