@@ -10,7 +10,7 @@
 #include "mapeditor.h"
 #include "simplescripteditor.h"
 #include "texteditor.h"
-//#include "xml.h"
+
 
 class Main : public QMainWindow 
 {
@@ -117,8 +117,10 @@ private slots:
 	void editVymLink();
 	void editOpenMultipleVymLinks();
     void editHeadingFinished();
+    void editAttributeFinished();
 public slots:
     void editHeading();
+    void editAttribute();
 	void editOpenVymLink();
 private slots:
 	void editDeleteVymLink();
@@ -126,8 +128,10 @@ private slots:
 	void editMapInfo();
     void editMoveUp();	
     void editMoveDown();	
+	void editSortChildren();
     void editToggleScroll();
     void editUnscrollChilds();
+    void editAddMapCenter();
     void editNewBranch();
     void editNewBranchBefore();
     void editNewBranchAbove();
@@ -180,6 +184,8 @@ public slots:
 	void settingsUndoLevels();
 	void settingsAutosaveToggle();
 	void settingsAutosaveTime();
+	void settingsWriteBackupFileToggle();
+	void settingsToggleAnimation();
 
 	void windowToggleNoteEditor();
 	void windowToggleHistory();
@@ -236,6 +242,8 @@ private:
 
 	QColor currentColor;
 
+	int xLinkMenuWidth;
+
 	QMenu *recentFilesMenu;
 	enum { MaxRecentFiles = 9 };
     QAction *recentFileActions[MaxRecentFiles];
@@ -243,6 +251,7 @@ private:
     QAction *macroActions[12];
 	QStringList macro;
 
+	QAction* actionFileNewCopy;
 	QAction* actionFileSave;
 	QAction* actionFilePrint;
 	QAction* actionEditUndo;
@@ -252,6 +261,7 @@ private:
 	QAction *actionEditPaste;
 	QAction *actionEditMoveUp;
 	QAction *actionEditMoveDown;
+	QAction *actionEditSortChildren;
 	QAction *actionEditToggleScroll;
 	QAction* actionEditOpenURL;
 	QAction* actionEditOpenURLTab;
@@ -269,6 +279,7 @@ private:
 	QAction *actionEditMapInfo;
 	QAction *actionEditHeading;
 	QAction *actionEditDelete;
+	QAction *actionEditAddMapCenter;
 	QAction *actionEditAddBranch;
 	QAction *actionEditAddBranchBefore;
 	QAction *actionEditAddBranchAbove;
@@ -322,6 +333,8 @@ private:
 	QAction* actionSettingsUseHideExport;
 	QAction* actionSettingsAutosaveToggle;
 	QAction* actionSettingsAutosaveTime;
+	QAction* actionSettingsWriteBackupFile;
+	QAction* actionSettingsUseAnimation;
 };
 
 
