@@ -1,7 +1,10 @@
 #include <QDateTime>
 
-#include "mapcenterobj.h"
 #include "floatimageobj.h"
+#include "geometry.h"
+#include "mapcenterobj.h"
+#include "mapeditor.h"
+
 
 /////////////////////////////////////////////////////////////////
 // MapCenterObj
@@ -21,6 +24,7 @@ MapCenterObj::MapCenterObj(QGraphicsScene* s) : BranchObj (s)
 MapCenterObj::~MapCenterObj() 
 {
 //    cout << "Destr MapCenterObj\n";
+	clear();
 }	
 
 void MapCenterObj::clear() 
@@ -47,6 +51,11 @@ void MapCenterObj::move (double x, double y)
 	BranchObj::move(x,y);
 }
 
+void MapCenterObj::move (QPointF absPos)
+{
+	BranchObj::move(absPos);
+}
+
 void MapCenterObj::moveBy (double x, double y)
 {
 	BranchObj::moveBy(x,y);
@@ -106,11 +115,11 @@ LinkableMapObj* MapCenterObj::findMapObj(QPointF p, LinkableMapObj *excludeLMO)
 		if (lmo!= NULL) return lmo;
 	}
 	// is p in MapCenter?
-	if (inBox (p) && (this != excludeLMO) ) return this;
+	if (inBox (p,clickBox) && (this != excludeLMO) ) return this;
 
 	// Search float images
 	for (int i=0; i<floatimage.size(); ++i)
-		if (floatimage.at(i)->inBox(p) && (floatimage.at(i) != excludeLMO) && floatimage.at(i)->getParObj()!= excludeLMO) return floatimage.at(i);
+		if (inBox(p,floatimage.at(i)->getClickBox()) && (floatimage.at(i) != excludeLMO) && floatimage.at(i)->getParObj()!= excludeLMO) return floatimage.at(i);
 
 	// nothing found
 	return NULL;
@@ -130,14 +139,15 @@ QString MapCenterObj::saveToDir (const QString &tmpdir,const QString &prefix, in
 	// Providing an ID for a branch makes export to XHTML easier
 	QString idAttr;
 	if (countXLinks()>0)
-		idAttr=attribut ("id",getSelectString());
+		idAttr=attribut ("id",mapEditor->getModel()->getSelectString(this)); //TODO directly access model
+
 	else
 		idAttr="";
 
 	QString linkAttr=getLinkAttr();
 
     s=beginElement ("mapcenter" 
-		+getOrnAttr() 
+		+getOrnXMLAttr() 
 		+areaAttr 
 		+idAttr 
 		+getIncludeImageAttr() );
