@@ -4,18 +4,21 @@
 #include <QGraphicsView>
 #include <QtNetwork>
 
-#include "mapcenterobj.h"
+#include "attribute.h"
 #include "file.h"
 #include "misc.h"
 #include "parser.h"
 #include "ornamentedobj.h"
 #include "selection.h"
 #include "settings.h"
+#include "vymmodel.h"
 
+class VymModel;
+class Selection;
 
 /*! \brief Main widget in vym to display and edit a map */
 
-class MapEditor : public QGraphicsView, public xmlObj {
+class MapEditor : public QGraphicsView, public XMLObj {
     Q_OBJECT
 
 public:
@@ -40,7 +43,7 @@ public:
 	};
     MapEditor(QWidget* parent=0);
 	~MapEditor();
-    MapCenterObj* getMapCenter();		//!< Return center of map
+	VymModel* getModel();
 	QGraphicsScene * getScene();
 	State getState();					//!< Return State of MapEditor
 	void setStateEditHeading (bool);	//!< If set to true, State will change to EditHeading
@@ -82,15 +85,42 @@ protected:
 		Additionally a comment is logged. 
 
 	*/	
-    void saveState(const SaveMode& savemode, const QString &undoSelection, const QString &undoCommand, const QString &redoSelection, const QString &redoCommand, const QString &comment, LinkableMapObj *saveSelection);
+    void saveState(
+		const SaveMode& savemode, 
+		const QString &undoSelection, 
+		const QString &undoCommand, 
+		const QString &redoSelection, 
+		const QString &redoCommand, 
+		const QString &comment, 
+		LinkableMapObj *saveSelection);
 	/*! Overloaded for convenience */
-    void saveStateChangingPart(LinkableMapObj *undoSelection, LinkableMapObj* redoSelection, const QString &redoCommand, const QString &comment);
+    void saveStateChangingPart(
+		LinkableMapObj *undoSelection, 
+		LinkableMapObj* redoSelection, 
+		const QString &redoCommand, 
+		const QString &comment);
 	/*! Overloaded for convenience */
-    void saveStateRemovingPart(LinkableMapObj *redoSelection, const QString &comment);
+    void saveStateRemovingPart(
+		LinkableMapObj *redoSelection, 
+		const QString &comment);
 	/*! Overloaded for convenience */
-    void saveState(LinkableMapObj *undoSelection, const QString &undoCommand, LinkableMapObj *redoSelection, const QString &redoCommand, const QString &comment); 
+    void saveState(
+		LinkableMapObj *undoSelection, 
+		const QString &undoCommand, 
+		LinkableMapObj *redoSelection, 
+		const QString &redoCommand, 
+		const QString &comment); 
 	/*! Overloaded for convenience */
-    void saveState(const QString &undoSelection, const QString &undoCommand, const QString &redoSelection, const QString &redoCommand, const QString &comment) ;
+    void saveState(
+		const QString &undoSelection, 
+		const QString &undoCommand, 
+		const QString &redoSelection, 
+		const QString &redoCommand, 
+		const QString &comment) ;
+    void saveState(
+		const QString &undoCommand, 
+		const QString &redoCommand, 
+		const QString &comment) ;
 
 public:	
 
@@ -134,16 +164,18 @@ public:
     ErrorCode load (QString, const LoadMode &, const FileType& );	// newmap, import/replace selection
 public:
 	/*! \brief Save the map to file */
-    int save(const SaveMode &);	
+    ErrorCode save(const SaveMode &);	
+	/* FIXME no needed any longer
 	void setZipped(bool);		//!< Set or unset compression of map with zip save map zipped
 	bool saveZipped();			//!< True, if file will be saved zipped
+	*/
     void print();				//!< Print the map
 	void setAntiAlias (bool);	//!< Set or unset antialiasing
 	void setSmoothPixmap(bool); //!< Set or unset smoothing of pixmaps
 private:
     QPixmap getPixmap();
-	void setHideTmpMode (BranchObj::HideTmpMode);	// temporary hide stuff
-	BranchObj::HideTmpMode getHideTmpMode();		// temporary hide stuff
+	void setHideTmpMode (HideTmpMode);	// temporary hide stuff
+	HideTmpMode getHideTmpMode();		// temporary hide stuff
 public:
 	/*! Set or unset temporary hiding of objects during export  */
 	void setExportMode (bool);
@@ -189,6 +221,7 @@ public:
     void moveRel (const double &x, const double &y);
     void moveBranchUp();	//!< Move branch up
     void moveBranchDown();	//!< Move branch down
+	void sortChildren();	//!< Sort children lexically
 private:	
 	void linkTo(const QString &);
 public:	
@@ -197,6 +230,13 @@ public:
 private:
 	void setHeadingInt(const QString &);
 	void setVymLinkInt(const QString &);	// Set vymLink for selection
+	/*! \brief Add new mapcenter
+
+	    Disclaimer: Still experimental, not fully supported.
+	*/	
+public:	
+    BranchObj* addMapCenter();		
+
 	/*! \brief Add new branch
 
 		Depending on num the new branch is created
@@ -207,6 +247,7 @@ private:
 		0..n	insert at a specific position in selections parent
 		(needed for free relinking)
 	*/	
+private:	
     BranchObj* addNewBranchInt(int);		// pos allows to add above/below selection
 public:	
 	/*! \Add new branch
@@ -225,6 +266,7 @@ public:
 	void unselect();						// before changing current noteedit
 	void reselect();						// after  changing current noteedit
 	bool select(const QString &);			// Select by string
+	bool select(LinkableMapObj *lmo);		// Select by pointer
 	QString getSelectString();
 private:	
 	void selectInt(LinkableMapObj*);	
@@ -319,6 +361,7 @@ public:
     void importDir();
 	void followXLink (int);
 	void editXLink (int);
+	AttributeTable* attributeTable();
     void testFunction1();					// just testing new stuff
     void testFunction2();					// just testing new stuff
 											// set /mainwindo/showTestMenu=true...
@@ -338,7 +381,6 @@ protected:
 	void dragLeaveEvent (QDragLeaveEvent *);
 	void dropEvent (QDropEvent *);
 
-	void timerEvent(QTimerEvent *event);
 
 protected:
 	void sendSelection();
@@ -354,12 +396,15 @@ private slots:
 	void displayNetworkError (QAbstractSocket::SocketError);
 
 	void autosave ();
+	void fileChanged();
 
 private:
 	State state;				// State of MapEditor
 	QGraphicsScene *mapScene;
-    MapCenterObj* mapCenter;
+	VymModel *model;					// Vym Map, includding several mapCenters
 	QTimer *autosaveTimer;
+	QTimer *fileChangedTimer;
+	QDateTime fileChangedTime;
 
 	bool adjustCanvasRequested;	// collect requests until end of user event
 	BranchObj *editingBO;		// entering Text into BO
@@ -390,6 +435,9 @@ private:
     QPointF movingObj_start;		// rel. pos of mouse to absPos 
     QPointF movingCont_start;		// inital pos of moving Content or
     QPointF movingVec;				// how far has Content moved
+
+	QPointF contextMenuPos;					// position where context event was triggered
+
     QPrinter* printer;				// Printing
 
     bool mapDefault;				// Flag if map is untouched
@@ -398,11 +446,14 @@ private:
 
 	Parser parser;				// Parser stuff for scripting
 
+	AttributeTable *attrTable;
+
 	bool printFrame;			// Print frame around map
 	bool printFooter;			// Print footer below map
 
 	bool zipped;				// should map be zipped
 	static	int mapNum;			// unique number for Editor
+	FileType fileType;			// type of file, e.g. vym, freemind...
 	QString fileName;			// short name of file (for tab)
 	QString filePath;			// path to file which will be saved
 	QString fileDir;			// dir where file is saved
@@ -424,8 +475,9 @@ private:
 	bool EOFind;				// true, if search failed
 
 	QPoint exportOffset;		// set before export, used in save
-	BranchObj::HideTmpMode hidemode;	// true while exporting to hide some stuff
+	HideTmpMode hidemode;	// true while exporting to hide some stuff
 
+	// Network connections **Experimental**
 	NetState netstate;			// offline, client, server
 	QTcpServer *tcpServer;		// Act as server in conference mode (experimental)
 	QList <QTcpSocket*> clientList;		// List of connected clients
@@ -436,9 +488,6 @@ private:
 	int port;					// server port of this client
 	void displayClientError(QAbstractSocket::SocketError socketError);
 
-
-	int timerId;				// animation timer
-	QList <MapObj*> animObjList;// list with animated objects
 };
 #endif
 
