@@ -102,50 +102,17 @@ void MapObj::moveBy (double x, double y)
 	clickBox.moveTo (clickBox.x()+x,clickBox.y()+y);
 }
 
-bool MapObj::inBox(const QPointF &p)
-{
-    if (p.x() >= clickBox.left() && p.x() <= clickBox.right()  
-	&& p.y() <= clickBox.bottom() && p.y() >= clickBox.top() )
-		return true;
-    return false;	
-}
-
 QRectF MapObj::getBBox()
 {
     return bbox;
 }
 
-QRectF MapObj::addBBox(QRectF r1, QRectF r2)
-{	
-	// Find smallest QRectF containing given rectangles
-
-	QRectF n;
-	// Set left border
-	if (r1.left() <= r2.left() )
-		n.setLeft(r1.left() );
-	else
-		n.setLeft(r2.left() );
-		
-	// Set top border		
-	if (r1.top() <= r2.top() )
-		n.setTop(r1.top() );
-	else
-		n.setTop(r2.top() );
-		
-	// Set right border
-	if (r1.right() <= r2.right() )
-		n.setRight(r2.right() );
-	else
-		n.setRight(r1.right() );
-		
-	// Set bottom 
-	if (r1.bottom() <= r2.bottom() )
-		n.setBottom(r2.bottom() );
-	else
-		n.setBottom(r1.bottom() );
-	return n;
+QRectF MapObj::getClickBox()
+{
+    return clickBox;
 }
 
+
 QSizeF MapObj::getSize()
 {
     return bbox.size();
@@ -162,6 +129,3 @@ void MapObj::setVisibility(bool v)
     visible=v;
 }
 
-void MapObj::animate()
-{
-}
