@@ -47,13 +47,7 @@ Options::Options() {}
 
 int Options::parse()
 {
-	QStringList arglist;
-	int i=0;
-	while ( i < qApp->argc())
-	{	
-		arglist.append (qApp->argv()[i]);
-		i++;
-	}
+	QStringList arglist=qApp->arguments();
 
 	// Get program name
 	progname=arglist.first();
@@ -61,7 +55,7 @@ int Options::parse()
 
 	// Work through rest of options
 	bool isFile;
-	for (i=0; i< arglist.size(); ++i)
+	for (int i=0; i< arglist.size(); ++i)
 	{
 		isFile=true;
 		if (arglist[i].left(1)=="-")
