@@ -1,10 +1,11 @@
 #ifndef ORNAMENTEDOBJ_H
 #define ORNAMENTEDOBJ_H
 
+#include "attribute.h"
 #include "frameobj.h"
 #include "linkablemapobj.h"
 
-/*! \brief Adds various ornaments to the class LinkableMapObj
+/*! \brief Adds various ornaments and data to the class LinkableMapObj
 
 The ornaments are:
 	- frame
@@ -15,6 +16,7 @@ The ornaments are:
 	- flags
 		- standard flags
 		- system flags
+	- attributes (key/value pairs)	
  */
 
 class OrnamentedObj:public LinkableMapObj {
@@ -54,13 +56,19 @@ public:
     virtual void setNote(QString);			// set note
     virtual void setNote(NoteObj);			// set note
     virtual QString getNote();				// returns note	(HTML)
+    virtual QString getNoteASCII(const QString &indent, const int &width); // returns note	(ASCII)
     virtual QString getNoteASCII();			// returns note	(ASCII)
     virtual QString getNoteOpenDoc();		// returns note	(OpenDoc)
+
     virtual void setURL (QString);
     virtual QString getURL ();
+
     virtual void setVymLink (QString);
     virtual QString getVymLink ();
 
+	virtual void setAttributes (const QList <Attribute> &al);
+	virtual QList <Attribute> getAttributes ();
+
 	virtual void clearStandardFlags();
 	virtual void toggleStandardFlag(QString, bool exclusive=false);
 	virtual void activateStandardFlag(QString);
@@ -74,7 +82,7 @@ public:
 	virtual void setHideInExport(bool);		// set export of object (and childs)
 	virtual bool hideInExport();
 	virtual bool isHidden ();
-	virtual QString getOrnAttr();			// get attributes for saveToDir
+	virtual QString getOrnXMLAttr();		// get attributes for saveToDir
 
 protected:
     HeadingObj *heading;			// Heading
@@ -86,6 +94,8 @@ protected:
 	QRectF ornamentsBBox;			// bbox of flags and heading
 	QString url;					// url to external doc
 	QString vymLink;				// path to another map
+	QList <Attribute> attributes;	// List with attributes
+
 	bool hideExport;				// hide in exports if set
 	bool hidden;					// true if temporary hidden
 };
