@@ -245,7 +245,7 @@ void Settings::setLocalEntry (const QString &fpath, const QString &key, const QS
 	}
 }
 
-QString Settings::getXMLData (const QString &fpath)
+QString Settings::getDataXML (const QString &fpath)
 {
 	QString s;
 	QStringList::Iterator itp=pathlist.begin();
