@@ -6,7 +6,6 @@
 
 #include "noteobj.h"
 #include "settings.h"
-#include "version.h"
 
 extern int statusbarTime;
 extern Settings settings;
@@ -453,7 +452,7 @@ void TextEditor::textLoad()
 {
 	if (state!=inactiveEditor)
 	{
-		if (e->text().length()) 
+		if (!isEmpty()) 
 		{
 			QMessageBox mb( vymName + " - " +tr("Note Editor"),
 				"Loading will overwrite the existing note",
