@@ -4,10 +4,10 @@
 #include <QString>
 
 #define __VYM_NAME "VYM"
-#define __VYM_VERSION "1.10.0"
-#define __VYM_CODENAME "Codename: 1.10.0-RC-3"
+#define __VYM_VERSION "1.12.2"
+#define __VYM_CODENAME "Maintenance Update"
 //#define __VYM_CODENAME "Codename: development version"
-#define __VYM_BUILD_DATE "September 4, 2007"
+#define __VYM_BUILD_DATE "2008-10-05"
 
 
 bool checkVersion(const QString &);
