@@ -8,6 +8,7 @@
 #include "file.h"
 #include "mapcenterobj.h"
 #include "mapeditor.h"
+#include "vymmodel.h"
 
 
 /*! \brief Base class for parsing maps from XML documents */
@@ -26,7 +27,7 @@ public:
 
 	virtual QString errorString()=0;
 	bool fatalError( const QXmlParseException&);
-	void setMapEditor (MapEditor*);
+	void setModel (VymModel *);
 	void setTmpDir (QString);
 	void setInputFile (QString);
 	void setLoadMode (const LoadMode &);
@@ -42,8 +43,7 @@ protected:
 //	QString htmldata;
 	int branchDepth; 
 //	NoteObj no;
-	MapCenterObj* mc;
-	MapEditor* me; 
+	VymModel *model;
 	QString tmpDir; 
 	QString inputFile;
 }; 
