@@ -68,7 +68,7 @@ void XSLTProc::process()
 	args << xslFile;
 	args << inputFile;
 	QString com=xsltprocessor+" "+args.join(" "); 
-	if (debug) cout <<"xsltproc executing:\n"<<com.ascii()<<endl;
+	if (debug) cout <<"xsltproc executing:\n"<<qPrintable(com)<<endl;
 	dia.append ("vym is executing: \n" + com );	
 	xsltProc->start(xsltprocessor,args);
 	if (!xsltProc->waitForStarted() )
@@ -78,11 +78,12 @@ void XSLTProc::process()
 	} else
 	{
 		if (!xsltProc->waitForFinished())
+		{
 			QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
 			   QObject::tr("%1 didn't exit normally").arg(xsltprocessor) +
 			   xsltProc->getErrout() );
-		else
 			if (xsltProc->exitStatus()>0) showOutput=true;
+		}	   
 			
 	}	
 	dia.append ("\n");
